Expander

Trait Expander 

pub trait Expander {
    // Required method
    fn fill_bytes(&mut self, okm: &mut [u8]) -> Result<usize, Error>;
}
Expander that, call read until enough bytes have been consumed.

Required Methods

fn fill_bytes(&mut self, okm: &mut [u8]) -> Result<usize, Error>

Fill the array with the expanded bytes, returning how many bytes were read.

Errors

If no bytes are left.

Implementors

Source

impl<HashT> Expander for ExpandMsgXof<HashT>

Source

impl<HashT> Expander for ExpanderXmd<'_, HashT>
where HashT: BlockSizeUser + Default + FixedOutput + HashMarker, HashT::OutputSize: IsLessOrEqual<HashT::BlockSize, Output = True>,